#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['icerok_server']

package_data = \
{'': ['*']}

install_requires = \
['pyserial >= 3.5']

entry_points = \
{'console_scripts': ['icerok-server = icerok_server:start']}

setup(name='icerok_server',
      version='0.1.11',
      description='Measure you FPGA circuit!',
      author='Juan Gonzalez (Obijuan)',
      author_email='obijuan.cube@gmail.com',
      url='https://github.com/FPGAwars/icerok-server-python',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
